# Having a sip
Contain common Python functions to help you have a sip instead of rebuilding them.


## Features
For more information, refer to the [documentation](https://having-a-sip.readthedocs.io/en/latest)

## Installation
The following command installs [Having a sip](https://pypi.org/project/having-a-sip) from the Python Package Index. You will need a working installation of Python and pip.
```
pip install having-a-sip
```

